/* Please do not attemp to run this program without reading the accompanying documentation. */

/*
File: extract_08.do
Date: May 2012
Desc: This program extracts and converts the Census's 2008 SIPP data.
Note: See copyright notice at the end of this program.
*/

/* Acknowledgements

This program builds on work by Heather Boushey and others at CEPR 
on previous versions of the SIPP. Please see http://ceprdata.org.

*/

/* USER NOTES

This program will read the 2008 SIPP panel into Stata format and label 
the variables and their values. The underlying data must be downloaded from 
the NBER (http://www.nber.org/data/sipp.html), or from the U.S. Census. 
The raw data will come in *.dat format. Downloading directions can 
be found at the CEPR websited (http:///www.cepr.net/data/sipp_extract.html). 

CEPR's extract programs are meant to substitute for the NBER *.dct and 
*.do files so these do not need to be downloaded from the NBER. In particular, 
the CEPR programs have changed the format of the variables necessary 
to generate the unique id from numeric into string in order to 
concatenate them correctly.

To run these programs, set the gnulin and directory macros below appropriately.

It is recommended that you have 1GB of ram memory. 

Please direct all questions to http://ceprdata.org.

*/

set more off
prog drop _all
capture log close
clear

	/* Windows vs. GNU/Linux */
global gnulin=1 /* set equal to zero for Windows; 1 if GNU/Linux */
	
	/* GNU/Linux */
if $gnulin==1 {
	/*If you run GNU/Linux, be sure to change $rootdir to match your root directory*/
	global rootdir "/home/ben/data/sipp/cepr/"
	global programs "${rootdir}do/extract/"
	global log "${programs}"
	global dictdir "${programs}"
	global rawdata "${rootdir}raw/"
	global output "$rawdata"
	global unzip "unzip -o"
}

	/* Windows */
if $gnulin==0 {
	/*If you run Windows, be sure to change $rootdir to match your root directory*/
	global rootdir "f:\_files\ceprdata\sipp"
	global programs "$rootdir\programs\extract\sipp08"
	global log "$rootdir\programs\extract\sipp08"
	global dictdir "$rootdir\programs\extract\sipp08"
	global rawdata "$rootdir\rawdata"
	global output "$rootdir\rawdata"
}

capture program drop loop
program define loop
	if "`1'" == "core" {
	/* uses Wave 1 dictionary for all core modules, wave 1-12 */
		foreach i of numlist 9/11 {

			global dct_name "${dictdir}sipp08w1.dct"
			global raw_name "${rawdata}l08puw`i'"


			clear
			cd $rawdata
			!$unzip $raw_name

			cd $programs
			do sipp08w1.do
		
			* gen unique id to merge
			sort ssuid eentaid epppnum
			egen id = concat(ssuid eentaid epppnum)

	
			rename swave wave
			rename srotaton rot
			sort id rot wave

			cd $output
			save sipp08w`i'.dta, replace


			cd $rawdata
			erase ${raw_name}.dat
		}
	}

	if "`1'" == "tm" {
		foreach i of numlist 1/7 {
			global dct_name "${dictdir}sippp08putm`i'.dct"
			global raw_name "${rawdata}p08putm`i'"
			
			clear
			cd $rawdata
			!$unzip $raw_name

			cd $programs
			do sippp08putm`i'.do
			
			* gen unique id to merge
			sort ssuid eentaid epppnum
			egen id = concat(ssuid eentaid epppnum)

			rename swave wave
			rename srotaton rot
			sort id rot wave

			cd $output
			save sipp08t`i'.dta, replace

			cd $rawdata
			erase ${raw_name}.dat
		}
	}

end

/*For longitidual weights*/
capture program drop lweights
program define lweights

	/*Macros for dictionary files and raw SIPP data files*/

	global dct_name "${dictdir}sipp08lw4.dct"
	global raw_name "${rawdata}lgtwgt2008w4"

	cd $rawdata
	!$unzip $raw_name

	quietly infile using $dct_name, using(${raw_name}.dat) clear

	cd $output
	sort ssuid epppnum
	save sipp08lwt.dta, replace
	clear

	cd $rawdata
	erase ${raw_name}.dat

end

loop core
*loop tm
*lweights




/*
Copyright 2010 Center for Economic and Policy Research
1621 Connecticut Avenue, NW
Suite 500
Washington, DC 20009
Tel: (202) 293-5380
Fax: (202) 588-1356
http://www.cepr.net

This program and all programs referenced in it are free software. You
can redistribute the program or modify it under the terms of the GNU
General Public License as published by the Free Software Foundation;
either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA.
*/



